/*****************************************************  Global Functions  *****************************************************

	Red Rapids
	797 N Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following functions are common to several Red Rapids applications.

	Rev History:	11-28-2018:		Initial release.

	Copyright (c) 2019  Red Rapids, Inc.

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
	files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
	modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
	is furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
	OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
	LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
	IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*****************************************************  Global Functions  *****************************************************/

#include "RRadapter.h"
#include "flash.h"
#include "global_functions.h"

// Report the firmware revision date (MMDDYYYY).
// Returns the firmware revision date in hex format, but it is not a hex value (e.g. 04/27/2012 returns 0x04272012).
unsigned FirmwareRevision(s_Handle *p_HW)
{
	unsigned long long value = 0;

	Read64(p_HW, BAR2, IDENTIFICATION, &value);

	return (unsigned long)(value & 0xFFFFFFFFull);
}

// Report the model number of the device.
// Returns the model number in hex format, but it is not a hex value (e.g. Model 266 returns 0x266).
unsigned ModelNumber(s_Handle *p_HW)
{
	unsigned long long value = 0;

	Read64(p_HW, BAR2, IDENTIFICATION, &value);

	return (unsigned long)((value >> 32) & 0x00000FFFull);
}

// Issue a software reset that is equivalent to a power-on reset.
void SoftwareReset(s_Handle *p_HW)
{
	Write64(p_HW, BAR0, SOFTWARE_RESET, 0x0ull);
}
